many_lints library

Many Lints - A collection of useful lint rules for Dart and Flutter.

This package provides custom lint rules, quick fixes, and code assists that integrate with the Dart analyzer and IDEs.

Usage

Add many_lints to your pubspec.yaml:

dev_dependencies:
  many_lints: ^0.1.0

Then enable the plugin in your analysis_options.yaml:

analyzer:
  plugins:
    - many_lints

Classes

ManyLintsPlugin
Many Lints - A collection of useful lint rules for Dart and Flutter.

Properties

plugin ManyLintsPlugin
Top-level plugin variable required by analysis_server_plugin.
final